@@ -1,4 +1,4 @@
-__version__ = '1.0.6'
+__version__ = '1.1.0'
 __author__ = 'Altair Bow'
 __author_email__ = 'altair.bow@foxmail.com'
 __description__ = 'Persistent database connection backends for Django'
@@ -9,6 +9,4 @@ def setup(**kwargs):
 
     for key, value in kwargs.items():
         if key in pool_container.pool_default_params:
-            pool_container.pool_default_params.update(
-                key=value
-            )
+            pool_container.pool_default_params[key] = value
